@@ -4,40 +4,52 @@
 reformat_data <- function(scores, labels,
                           modname = as.character(NA), dsid = 1L,
                           posclass = NULL, na_worst = TRUE,
-                          ties_method = "equiv", ...) {
+                          ties_method = "equiv", mode = "rocprc", ...) {
 
   # === Validate input arguments ===
+  new_ties_method <- .pmatch_tiesmethod(ties_method, ...)
+  new_na_worst <- .get_new_naworst(na_worst, ...)
+  new_mode <- .pmatch_mode(mode)
   .validate_reformat_data_args(scores, labels, modname = modname, dsid = dsid,
-                               posclass = posclass, na_worst = na_worst,
-                               ties_method = ties_method, ...)
+                               posclass = posclass, na_worst = new_na_worst,
+                               ties_method = new_ties_method, mode = new_mode,
+                               ...)
 
   # === Reformat input data ===
-  # Get score ranks and sorted indices
-  sranks <- .rank_scores(scores, na_worst, ties_method, validate = FALSE)
-  ranks <- sranks[["ranks"]]
-  rank_idx <- sranks[["rank_idx"]]
-
   # Get a factor with "positive" and "negative"
   fmtlabs <- .factor_labels(labels, posclass, validate = FALSE)
 
-  # === Create an S3 object ===
-  s3obj <- structure(list(scores = scores,
-                          labels = fmtlabs[["labels"]],
-                          ranks = ranks,
-                          rank_idx = rank_idx),
-                     class = "fmdat")
+  if (mode == "aucroc") {
+    # === Create an S3 object ===
+    s3obj <- structure(list(scores = scores,
+                            labels = fmtlabs[["labels"]]),
+                       class = "sdat")
+  } else {
+    # Get score ranks and sorted indices
+    sranks <- .rank_scores(scores, new_na_worst, new_ties_method,
+                           validate = FALSE)
+    ranks <- sranks[["ranks"]]
+    rank_idx <- sranks[["rank_idx"]]
+
+    # === Create an S3 object ===
+    s3obj <- structure(list(scores = scores,
+                            labels = fmtlabs[["labels"]],
+                            ranks = ranks,
+                            rank_idx = rank_idx),
+                       class = "fmdat")
+  }
 
   # Set attributes
   attr(s3obj, "modname") <- modname
   attr(s3obj, "dsid") <- dsid
   attr(s3obj, "nn") <- fmtlabs[["nn"]]
   attr(s3obj, "np") <- fmtlabs[["np"]]
-  attr(s3obj, "args") <- list(posclass = posclass, na_worst = na_worst,
-                              ties_method = ties_method,
+  attr(s3obj, "args") <- list(posclass = posclass, na_worst = new_na_worst,
+                              ties_method = new_ties_method,
                               modname = modname, dsid = dsid)
   attr(s3obj, "validated") <- FALSE
 
-  # Call .validate.fmdat()
+  # Call .validate.fmdat() / .validate.sdat()
   .validate(s3obj)
 }
 
@@ -97,7 +109,7 @@ reformat_data <- function(scores, labels,
 #
 .validate_reformat_data_args <- function(scores, labels, modname, dsid,
                                          posclass, na_worst, ties_method,
-                                         ...) {
+                                         mode, ...) {
 
   # Check '...'
   arglist <- list(...)
@@ -124,6 +136,9 @@ reformat_data <- function(scores, labels,
   # Check ties_method
   .validate_ties_method(ties_method)
 
+  # Check mode
+  .validate_mode(mode)
+
 }
 
 #
@@ -136,7 +151,7 @@ reformat_data <- function(scores, labels,
   }
 
   # Validate class items and attributes
-  item_names <- c("labels", "ranks", "rank_idx")
+  item_names <- c("scores", "labels", "ranks", "rank_idx")
   attr_names <- c("modname", "dsid", "nn", "np", "args", "validated")
   arg_names <- c("posclass", "na_worst", "ties_method", "modname", "dsid")
   .validate_basic(fmdat, "fmdat", "reformat_data", item_names, attr_names,
@@ -168,3 +183,34 @@ reformat_data <- function(scores, labels,
   fmdat
 }
 
+#
+# Validate 'sdat' object generated by reformat_data()
+#
+.validate.sdat <- function(sdat) {
+  # Need to validate only once
+  if (methods::is(sdat, "sdat") && attr(sdat, "validated")) {
+    return(sdat)
+  }
+
+  # Validate class items and attributes
+  item_names <- c("scores", "labels")
+  attr_names <- c("modname", "dsid", "nn", "np", "args", "validated")
+  arg_names <- c("posclass", "na_worst", "ties_method", "modname", "dsid")
+  .validate_basic(sdat, "sdat", "reformat_data", item_names, attr_names,
+                  arg_names)
+
+  # Check values of class items
+  if (length(sdat[["labels"]]) == 0
+      || length(sdat[["labels"]]) != length(sdat[["scores"]])) {
+    stop("List items in sdat must be all the same lengths", call. = FALSE)
+  }
+
+  # Labels
+  assertthat::assert_that(is.atomic(sdat[["labels"]]),
+                          is.vector(sdat[["labels"]]),
+                          is.numeric(sdat[["labels"]]))
+
+  attr(sdat, "validated") <- TRUE
+  sdat
+}
+
